==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/de_DE.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "Unknown user" : "Unbekannter Benutzer",
    "New comment …" : "Neuer Kommentar ...",
    "Delete comment" : "Kommentar löschen",
    "Post" : "Speichern",
    "Cancel" : "Abbrechen",
    "Edit comment" : "Kommentar bearbeiten",
    "[Deleted user]" : "[gelöschter Benutzer]",
    "No comments yet, start the conversation!" : "Keine Kommentare bisher. Beginnen Sie die Diskussion!",
    "More comments …" : "Weitere Kommentare ...",
    "Save" : "Speichern",
    "Allowed characters {count} of {max}" : "{count} von {max} Zeichen benutzt",
    "Error occurred while retrieving comment with id {id}" : "Es ist ein Fehler beim Empfangen des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while updating comment with id {id}" : "Es ist ein Fehler beim Aktualisieren des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while posting comment" : "Es ist ein Fehler beim Veröffentlichen des Kommentars aufgetreten",
    "_%n unread comment_::_%n unread comments_" : ["%n ungelesener Kommentar","%n ungelesene Kommentare"],
    "Comment" : "Kommentar",
    "You commented" : "Sie haben kommentiert",
    "%1$s commented" : "%1$s kommentierte",
    "{author} commented" : "{author} kommentierte",
    "You commented on %1$s" : "Sie haben %1$s kommentiert",
    "You commented on {file}" : "Sie haben {file} kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentierte %2$s",
    "{author} commented on {file}" : "{author} hat {file} kommentiert",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Ein (nun) gelöschter Benutzer hat Sie in einem Kommentar zu \"%s\" erwähnt",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Ein (nun) gelöschter Benutzer hat Sie in einem Kommentar zu “{file}” erwähnt",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s hat Sie in einem Kommentar zu “%2$s” erwähnt.",
    "{user} mentioned you in a comment on “{file}”" : "{user} hat Sie in einem Kommentar zu “{file}” erwähnt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.3-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/de_DE.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Kommentare",
    "Unknown user" : "Unbekannter Benutzer",
    "New comment …" : "Neuer Kommentar …",
    "Delete comment" : "Kommentar löschen",
    "Post" : "Speichern",
    "Cancel" : "Abbrechen",
    "Edit comment" : "Kommentar bearbeiten",
    "[Deleted user]" : "[gelöschter Benutzer]",
    "No comments yet, start the conversation!" : "Keine Kommentare bisher. Beginnen Sie die Diskussion!",
    "More comments …" : "Weitere Kommentare …",
    "Save" : "Speichern",
    "Allowed characters {count} of {max}" : "{count} von {max} Zeichen benutzt",
    "Error occurred while retrieving comment with id {id}" : "Es ist ein Fehler beim Empfangen des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while updating comment with id {id}" : "Es ist ein Fehler beim Aktualisieren des Kommentars mit der ID {id} aufgetreten",
    "Error occurred while posting comment" : "Es ist ein Fehler beim Veröffentlichen des Kommentars aufgetreten",
    "_%n unread comment_::_%n unread comments_" : ["%n ungelesener Kommentar","%n ungelesene Kommentare"],
    "Comment" : "Kommentar",
    "You commented" : "Sie haben kommentiert",
    "%1$s commented" : "%1$s kommentierte",
    "{author} commented" : "{author} kommentierte",
    "You commented on %1$s" : "Sie haben %1$s kommentiert",
    "You commented on {file}" : "Sie haben {file} kommentiert",
    "%1$s commented on %2$s" : "%1$s kommentierte %2$s",
    "{author} commented on {file}" : "{author} hat {file} kommentiert",
    "<strong>Comments</strong> for files" : "<strong>Kommentare</strong> für Dateien",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Ein (nun) gelöschter Benutzer hat Sie in einem Kommentar zu \"%s\" erwähnt",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Ein (nun) gelöschter Benutzer hat Sie in einem Kommentar zu “{file}” erwähnt",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s hat Sie in einem Kommentar zu “%2$s” erwähnt.",
    "{user} mentioned you in a comment on “{file}”" : "{user} hat Sie in einem Kommentar zu “{file}” erwähnt"
},
"nplurals=2; plural=(n != 1);");
